#!/usr/bin/perl -T

# $Id: expire-quarantine-cache.pl 897 2005-12-23 03:28:31Z dmorton $

########################################################################
# MAIA MAILGUARD LICENSE v.1.0
#
# Copyright 2004 by Robert LeBlanc <rjl@renaissoft.com>
#                   David Morton   <mortonda@dgrmm.net>
# All rights reserved.
#
# PREAMBLE
#
# This License is designed for users of Maia Mailguard
# ("the Software") who wish to support the Maia Mailguard project by
# leaving "Maia Mailguard" branding information in the HTML output
# of the pages generated by the Software, and providing links back
# to the Maia Mailguard home page.  Users who wish to remove this
# branding information should contact the copyright owner to obtain
# a Rebranding License.
#
# DEFINITION OF TERMS
#
# The "Software" refers to Maia Mailguard, including all of the
# associated PHP, Perl, and SQL scripts, documentation files, graphic
# icons and logo images.
#
# GRANT OF LICENSE
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# 3. The end-user documentation included with the redistribution, if
#    any, must include the following acknowledgment:
#
#    "This product includes software developed by Robert LeBlanc
#    <rjl@renaissoft.com>."
#
#    Alternately, this acknowledgment may appear in the software itself,
#    if and wherever such third-party acknowledgments normally appear.
#
# 4. At least one of the following branding conventions must be used:
#
#    a. The Maia Mailguard logo appears in the page-top banner of
#       all HTML output pages in an unmodified form, and links
#       directly to the Maia Mailguard home page; or
#
#    b. The "Powered by Maia Mailguard" graphic appears in the HTML
#       output of all gateway pages that lead to this software,
#       linking directly to the Maia Mailguard home page; or
#
#    c. A separate Rebranding License is obtained from the copyright
#       owner, exempting the Licensee from 4(a) and 4(b), subject to
#       the additional conditions laid out in that license document.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
########################################################################

    use strict;
    use DBI;

    # CONFIGURE THIS: Location of your database.cfg file
    my $cfg = "/var/amavisd/maia/scripts/database.cfg";

########################################################################
# End of user-configurable portion.  There should be no need to modify #
# anything below this point.                                           #
########################################################################

    # Retrieve the string value associated with a key in the database.cfg file.
    sub get_string_key($$)
    {
       my ($file, $key) = @_;

       if ($file =~ /\n[ \t]*$key[ \t]*=[ \t]*\"(.*)\"/) {
          return ($1);
       } else {
          die ("Maia: [get_string_key] Unable to find $key value in $file\n");
       }
    }

    # Determine the database type: "mysql" or "pg"
    sub get_db_type($) {
    	my($dbh) = @_;

    	return $dbh->{Driver}->{Name};
    }

    # Read a single value from Maia's configuration table.
    sub get_config_value($$) {
        my($dbh, $key) = @_;
        my($sth, @row, $select);
        my $value = undef;

        $select = "SELECT " . $key . " FROM maia_config WHERE id = 0";
        $select = $1 if $select =~ /^(.*)$/si; # untaint
        $sth = $dbh->prepare($select)
                   or die (sprintf("Maia: [get_config_value] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [get_config_value] Couldn't execute query: %s", $dbh->errstr));
        if (@row = $sth->fetchrow_array()) {
            $value = $row[0];
        }
        $sth->finish;

        return $value;
    }


    # Delete one specific mail item and all references to it.
    sub delete_mail_item($$) {
    	my($dbh, $mail_id) = @_;
    	my($sth, $delete);

        $mail_id = $1 if $mail_id =~ /^([0-9]*)$/si; # untaint

        # Delete the mail item itself
        $delete = "DELETE FROM maia_mail WHERE id = ?";
        $sth = $dbh->prepare($delete)
                    or die (sprintf("Maia: [delete_mail_item] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_item] Couldn't execute query: %s", $dbh->errstr));

        # Delete all recipient references to the mail item
        $delete = "DELETE FROM maia_mail_recipients WHERE mail_id = ?";
        $sth = $dbh->prepare($delete)
                    or die (sprintf("Maia: [delete_mail_item] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_item] Couldn't execute query: %s", $dbh->errstr));

        # Delete any virus references to the mail item
        $delete = "DELETE FROM maia_viruses_detected WHERE mail_id = ?";
        $sth = $dbh->prepare($delete)
                    or die (sprintf("Maia: [delete_mail_item] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_item] Couldn't execute query: %s", $dbh->errstr));

        # Delete any SpamAssassin rule references to the mail item
        $delete = "DELETE FROM maia_sa_rules_triggered WHERE mail_id = ?";
        $sth = $dbh->prepare($delete)
                     or die (sprintf("Maia: [delete_mail_item] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_item] Couldn't execute query: %s", $dbh->errstr));

        # Delete any banned file attachment references to the mail item
        $delete = "DELETE FROM maia_banned_attachments_found WHERE mail_id = ?";
        $sth = $dbh->prepare($delete)
                    or die (sprintf("Maia: [delete_mail_item] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_item] Couldn't execute query: %s", $dbh->errstr));

    }


    # Delete mail references for all recipients who see this mail item
    # as Suspected (S)pam, (V)irus, (B)ad Header, or Banned (F)iles.
    # Delete the mail item itself if there are no other recipients.
    sub delete_mail_references($$$) {
        my($dbh, $mail_id, $op) = @_;
        my($sth, $delete, $select);

        $mail_id = $1 if $mail_id =~ /^([0-9]*)$/si; # untaint

		if ($op eq "spam") {
	        # Delete mail references for all recipients
	        # who see this mail item as suspected spam,
	        # virus-infected, a banned attachment, or an
	        # invalid mail header.
	        $delete = "DELETE FROM maia_mail_recipients " .
	                  "WHERE (type = 'S' OR type = 'B' OR type = 'F' OR type = 'V') " .
	                  "AND mail_id = ?";
		} else {
		    # Delete mail references for all recipients
	        # who see this mail item as suspected ham.
	        $delete = "DELETE FROM maia_mail_recipients " .
	                  "WHERE type = 'H' " .
	                  "AND mail_id = ?";


		}
        $sth = $dbh->prepare($delete)
                   or die (sprintf("Maia: [delete_mail_references] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_references] Couldn't execute query: %s", $dbh->errstr));

        # See if any other mail references exist for this mail
        # item, i.e. any other recipients.
        $select = "SELECT recipient_id FROM maia_mail_recipients " .
                  "WHERE mail_id = ?";
        $sth = $dbh->prepare($select)
                   or die (sprintf("Maia: [delete_mail_references] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute($mail_id)
            or die (sprintf("Maia: [delete_mail_references] Couldn't execute query: %s", $dbh->errstr));

        # If no other recipients exist for this mail item,
        # delete the mail item itself.
        if (!$sth->fetchrow_array()) {
            delete_mail_item($dbh, $mail_id);
        }
        $sth->finish;
    }


    # Expire quarantined items [SVBF] older than the specified
    # expiration period.
    sub expire_quarantine($) {
        my($dbh) = @_;
        my($select, $sth, @row);
        my($days, $expiry_count);
        my $secsperday = 24 * 60 * 60;
        my $dbtype = get_db_type($dbh);

        $days = get_config_value($dbh, "expiry_period");
        $days = $1 if $days =~ /^([1-9]+[0-9]*)$/si; # untaint
        my $secs = $days * $secsperday;
        print "Expiring quarantined items [SVBF] older than " . $days . " days\n";
        $select = "SELECT DISTINCT maia_mail.id, maia_mail.received_date " .
                  "FROM maia_mail, maia_mail_recipients " .
                  "WHERE maia_mail.id = maia_mail_recipients.mail_id " .
                  "AND (maia_mail_recipients.type = 'S' OR " .
                       "maia_mail_recipients.type = 'B' OR " .
                       "maia_mail_recipients.type = 'F' OR " .
                       "maia_mail_recipients.type = 'V') ";
        if ($dbtype =~ /^mysql$/si) {
            $select .= "AND maia_mail.received_date < DATE_SUB(CURRENT_TIMESTAMP, INTERVAL " . $secs . " SECOND)";
        } elsif ($dbtype =~ /^pg$/si) {
            $select .= "AND maia_mail.received_date < NOW() - INTERVAL '" . $secs . " SECOND'";
        }
        $sth = $dbh->prepare($select)
                   or die (sprintf("Maia: [expire_quarantine] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [expire_quarantine] Couldn't execute query: %s", $dbh->errstr));
        $expiry_count = 0;
        while (@row = $sth->fetchrow_array()) {
            delete_mail_references($dbh, $row[0], "spam");
            $expiry_count++;
        }
        $sth->finish;

        return $expiry_count;
    }


    # Expire cached ham items [H] older than the specified
    # expiration period.
    sub expire_ham_cache($) {
        my($dbh) = @_;
        my($select, $sth, @row);
        my($days, $expiry_count);
        my $secsperday = 24 * 60 * 60;
        my $dbtype = get_db_type($dbh);

        $days = get_config_value($dbh, "ham_cache_expiry_period");
        $days = $1 if $days =~ /^([1-9]+[0-9]*)$/si; # untaint
        my $secs = $days * $secsperday;
        print "Expiring cached ham items [H] older than " . $days . " days\n";
        $select = "SELECT DISTINCT maia_mail.id, maia_mail.received_date " .
                  "FROM maia_mail, maia_mail_recipients " .
                  "WHERE maia_mail.id = maia_mail_recipients.mail_id " .
                  "AND maia_mail_recipients.type = 'H' ";
        if ($dbtype =~ /^mysql$/si) {
            $select .= "AND maia_mail.received_date < DATE_SUB(CURRENT_TIMESTAMP, INTERVAL " . $secs . " SECOND)";
        } elsif ($dbtype =~ /^pg$/si) {
            $select .= "AND maia_mail.received_date < NOW() - INTERVAL '" . $secs . " SECOND'";
        }
        $sth = $dbh->prepare($select)
                   or die (sprintf("Maia: [expire_ham_cache] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [expire_ham_cache] Couldn't execute query: %s", $dbh->errstr));
        $expiry_count = 0;
        while (@row = $sth->fetchrow_array()) {
            delete_mail_references($dbh, $row[0], "ham");
            $expiry_count++;
        }
        $sth->finish;

        return $expiry_count;
    }

    sub expire_orphans($) {
        my($dbh) = @_;
        my($select, $sth, @row);
        my($expiry_count);
    	my $secsperhour = 60 * 60;
        my $dbtype = get_db_type($dbh);

        print "Expiring orphaned items older than one hour\n";
        $select = "SELECT DISTINCT maia_mail.id, maia_mail_recipients.mail_id " .
                  "FROM maia_mail " .
                  "LEFT JOIN maia_mail_recipients ".
                  "ON maia_mail.id = maia_mail_recipients.mail_id " .
                  "WHERE maia_mail_recipients.type IS NULL ";
        if ($dbtype =~ /^mysql$/si) {
            $select .= "AND maia_mail.received_date < DATE_SUB(CURRENT_TIMESTAMP, INTERVAL " . 1 * $secsperhour . " SECOND)";
        } elsif ($dbtype =~ /^pg$/si) {
            $select .= "AND maia_mail.received_date < NOW() - INTERVAL '" . 1 * $secsperhour . " SECOND'";
        }
        $sth = $dbh->prepare($select)
                   or die (sprintf("Maia: [expire_quarantine] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [expire_quarantine] Couldn't execute query: %s", $dbh->errstr));
        $expiry_count = 0;
        while (@row = $sth->fetchrow_array()) {
            print "deleting ORPHAN " . $row[0] ."\n";
            delete_mail_item($dbh, $row[0]);
            $expiry_count++;
        }
        $sth->finish;

        return $expiry_count;
    }
    sub expire_strays($) {
	my($dbh) = @_;
	my($select, $sth, @row);
	my($expiry_count);
      
	print "Expiring Stray Mail Recipient reference with no Mail Item\n";
	$select = "SELECT maia_mail_recipients.mail_id " .
	    "FROM maia_mail_recipients " .
	    "LEFT JOIN maia_mail " .
	    "ON maia_mail.id = maia_mail_recipients.mail_id " .
	    "WHERE maia_mail.contents IS NULL ";

	$sth= $dbh->prepare($select)
	    or die (sprintf("Maia: [expire_quarantine] Couldn't prepare query: %s", $dbh->errstr));
	$sth->execute()
            or die (sprintf("Maia: [expire_quarantine] Couldn't execute query: %s", $dbh->errstr));
	$expiry_count = 0;
	while (@row = $sth->fetchrow_array()) {
	    print "deleting STRAY RECIPIENT " . $row[0] . "\n";
	    # calling delete_mail_item to delete the reference in case there are entries in other tables too.
	    delete_mail_item($dbh, $row[0]);
	    $expiry_count++;
	}
	$sth->finish;
	
	return $expiry_count;
    }
    sub count_ham_cache($) {
	my($dbh) = @_;
	my($select, $sth, @row);
        my($ham_count);

	$select = "SELECT COUNT(DISTINCT maia_mail_recipients.mail_id) " .
                  "FROM maia_mail_recipients " .
                  "WHERE maia_mail_recipients.type = 'H' ";
	
	$sth= $dbh->prepare($select)
	    or die (sprintf("Maia: [expire_quarantine] Couldn't prepare query: %s", $dbh->errstr));
	$sth->execute()
	    or die (sprintf("Maia: [expire_quarantine] Couldn't execute query: %s", $dbh->errstr));
	@row = $sth->fetchrow_array();
	$ham_count = $row[0];
	
	$sth->finish;

	return $ham_count;
	    
    }
    sub count_q_cache($) {
        my($dbh) = @_;
        my($select, $sth, @row);
        my($q_count);

        $select = "SELECT COUNT(DISTINCT maia_mail_recipients.mail_id) " .
                  "FROM maia_mail_recipients " .
                  "WHERE (maia_mail_recipients.type = 'S' OR " .
                       "maia_mail_recipients.type = 'B' OR " .
                       "maia_mail_recipients.type = 'F' OR " .
                       "maia_mail_recipients.type = 'V') ";

        $sth= $dbh->prepare($select)
            or die (sprintf("Maia: [expire_quarantine] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [expire_quarantine] Couldn't execute query: %s", $dbh->errstr));
        @row = $sth->fetchrow_array();
        $q_count = $row[0];

        $sth->finish;

        return $q_count;

    }

    # Expire token older than the specified
    # expiration period.
    sub expire_tokens($) {
        my($dbh) = @_;
        my($delete, $sth, @row);

        print "Expiring tokens due to expire now\n";
        $delete = "DELETE FROM maia_tokens where expires < NOW()";
        $sth = $dbh->prepare($delete)
                   or die (sprintf("Maia: [expire_tokens] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [expire_tokens] Couldn't execute query: %s", $dbh->errstr));
        $sth->finish();
    }

    # Read the database configuration file into memory once
    open CONFIGFILE, "<" . $cfg
        or die ("Maia: [expire-quarantine-cache] Unable to open $cfg\n");
    my($config) = "";
    my $line;
    while ($line = <CONFIGFILE>) {
        $config .= $line;
    }
    close CONFIGFILE;

    # Connect to the database
    my $dsn = get_string_key($config, "dsn");
    my $username = get_string_key($config, "username");
    my $password = get_string_key($config, "password");
    my $dbh = DBI->connect($dsn, $username, $password)
                       or die("Can't connect to SQL database");

    my $qcount = expire_quarantine($dbh);
    my $hcount = expire_ham_cache($dbh);
    my $cleanup = expire_orphans($dbh);
    my $strayclean = expire_strays($dbh);
    my $curhamcount = count_ham_cache($dbh);
    my $curqcount = count_q_cache($dbh);
    expire_tokens($dbh);

    print $qcount . " quarantined items expired\n";
    print $hcount . " cached ham items expired\n";
    if ($cleanup > 0) {
        print $cleanup . " orphaned items expired - please investigate!\n";
    }
    if ($strayclean > 0) {
	print $strayclean . " stray items expired - please investigate!\n";
    } 
    print "\n";
    print "Current Cache After Expiration:\n";
    print "Quarantined Items: " . $curqcount . "\n";
    print "Ham Items: " . $curhamcount . "\n";
    # Disconnect from the database
    $dbh->disconnect;

    # We're done.
    exit;
