#!/usr/bin/perl -T

# $Id: stats-snapshot.pl 897 2005-12-23 03:28:31Z dmorton $

########################################################################
# MAIA MAILGUARD LICENSE v.1.0
#
# Copyright 2004 by Robert LeBlanc <rjl@renaissoft.com>
#                   David Morton   <mortonda@dgrmm.net>
# All rights reserved.
#
# PREAMBLE
#
# This License is designed for users of Maia Mailguard
# ("the Software") who wish to support the Maia Mailguard project by
# leaving "Maia Mailguard" branding information in the HTML output
# of the pages generated by the Software, and providing links back
# to the Maia Mailguard home page.  Users who wish to remove this
# branding information should contact the copyright owner to obtain
# a Rebranding License.
#
# DEFINITION OF TERMS
#
# The "Software" refers to Maia Mailguard, including all of the
# associated PHP, Perl, and SQL scripts, documentation files, graphic
# icons and logo images.
#
# GRANT OF LICENSE
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# 3. The end-user documentation included with the redistribution, if
#    any, must include the following acknowledgment:
#
#    "This product includes software developed by Robert LeBlanc
#    <rjl@renaissoft.com>."
#
#    Alternately, this acknowledgment may appear in the software itself,
#    if and wherever such third-party acknowledgments normally appear.
#
# 4. At least one of the following branding conventions must be used:
#
#    a. The Maia Mailguard logo appears in the page-top banner of
#       all HTML output pages in an unmodified form, and links
#       directly to the Maia Mailguard home page; or
#
#    b. The "Powered by Maia Mailguard" graphic appears in the HTML
#       output of all gateway pages that lead to this software,
#       linking directly to the Maia Mailguard home page; or
#
#    c. A separate Rebranding License is obtained from the copyright
#       owner, exempting the Licensee from 4(a) and 4(b), subject to
#       the additional conditions laid out in that license document.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
########################################################################

    use strict;
    use DBI;

    # CONFIGURE THIS: Location of your database.cfg file
    my $cfg = "/var/amavisd/maia/scripts/database.cfg";

########################################################################
# End of user-configurable portion.  There should be no need to modify #
# anything below this point.                                           #
########################################################################

    # Retrieve the string value associated with a key in the database.cfg file.
    sub get_string_key($$)
    {
       my ($file, $key) = @_;

       if ($file =~ /\n[ \t]*$key[ \t]*=[ \t]*\"(.*)\"/) {
          return ($1);
       } else {
          die ("Maia: [get_string_key] Unable to find $key value in $file\n");
       }
    }


    sub get_db_type($) {
    	my($dbh) = @_;

    	return $dbh->{Driver}->{Name};
    }


    sub update_stats($$) {
        my($dbh, $type) = @_;
        my($select, $insert, $delete, $sth, $sth2, $sth3, @row, @row2, $user_id);
        my($total_ham_items, $total_ham_size);
        my($total_spam_items, $total_spam_size);
        my($total_virus_items, $total_virus_size);
        my($total_fp_items, $total_fp_size);
        my($total_fn_items, $total_fn_size);
        my($total_banned_file_items, $total_banned_file_size);
        my($total_bad_header_items, $total_bad_header_size);
        my($total_wl_items, $total_wl_size);
        my($total_bl_items, $total_bl_size);
        my($total_oversized_items, $total_oversized_size);
        my($dbtype) = get_db_type($dbh);

        $type = $1 if $type =~ /^([YMDH])$/si; # untaint

        $select = "SELECT user_id FROM maia_stats";
        $sth = $dbh->prepare($select)
                   or die (sprintf("Maia: [update_stats] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [update_stats] Couldn't execute query: %s", $dbh->errstr));
        while (@row = $sth->fetchrow_array()) {
            $user_id = $1 if $row[0] =~ /^([0-9]+)$/si; # untaint

            $select = "SELECT total_ham_items, total_ham_size, " .
                             "total_spam_items, total_spam_size, " .
                             "total_virus_items, total_virus_size, " .
                             "total_fp_items, total_fp_size, " .
                             "total_fn_items, total_fn_size, " .
                             "total_banned_file_items, total_banned_file_size, " .
                             "total_bad_header_items, total_bad_header_size, " .
                             "total_wl_items, total_wl_size, " .
                             "total_bl_items, total_bl_size, " .
                             "total_oversized_items, total_oversized_size " .
                      "FROM maia_stats WHERE user_id = ?";

            $sth2 = $dbh->prepare($select)
                       or die (sprintf("Maia: [update_stats] Couldn't prepare query: %s", $dbh->errstr));
            $sth2->execute($user_id)
                or die (sprintf("Maia: [update_stats] Couldn't execute query: %s", $dbh->errstr));
            if (@row2 = $sth2->fetchrow_array()) {
            	$total_ham_items = $1 if $row2[0] =~ /^([0-9]+)$/si; # untaint
            	$total_ham_size = $1 if $row2[1] =~ /^([0-9]+)$/si; # untaint
            	$total_spam_items = $1 if $row2[2] =~ /^([0-9]+)$/si; # untaint
            	$total_spam_size = $1 if $row2[3] =~ /^([0-9]+)$/si; # untaint
            	$total_virus_items = $1 if $row2[4] =~ /^([0-9]+)$/si; # untaint
            	$total_virus_size = $1 if $row2[5] =~ /^([0-9]+)$/si; # untaint
            	$total_fp_items = $1 if $row2[6] =~ /^([0-9]+)$/si; # untaint
            	$total_fp_size = $1 if $row2[7] =~ /^([0-9]+)$/si; # untaint
            	$total_fn_items = $1 if $row2[8] =~ /^([0-9]+)$/si; # untaint
            	$total_fn_size = $1 if $row2[9] =~ /^([0-9]+)$/si; # untaint
            	$total_banned_file_items = $1 if $row2[10] =~ /^([0-9]+)$/si; # untaint
            	$total_banned_file_size = $1 if $row2[11] =~ /^([0-9]+)$/si; # untaint
            	$total_bad_header_items = $1 if $row2[12] =~ /^([0-9]+)$/si; # untaint
            	$total_bad_header_size = $1 if $row2[13] =~ /^([0-9]+)$/si; # untaint
            	$total_wl_items = $1 if $row2[14] =~ /^([0-9]+)$/si; # untaint
            	$total_wl_size = $1 if $row2[15] =~ /^([0-9]+)$/si; # untaint
            	$total_bl_items = $1 if $row2[16] =~ /^([0-9]+)$/si; # untaint
            	$total_bl_size = $1 if $row2[17] =~ /^([0-9]+)$/si; # untaint
            	$total_oversized_items = $1 if $row2[18] =~ /^([0-9]+)$/si; # untaint
            	$total_oversized_size = $1 if $row2[19] =~ /^([0-9]+)$/si; # untaint

                $insert = "INSERT INTO maia_stats_history (user_id, " .
                                                          "type, " .
                                                          "taken_at, " .
                                                          "total_ham_items, total_ham_size, " .
                                                          "total_spam_items, total_spam_size, " .
                                                          "total_virus_items, total_virus_size, " .
                                                          "total_fp_items, total_fp_size, " .
                                                          "total_fn_items, total_fn_size, " .
                                                          "total_banned_file_items, total_banned_file_size, " .
                                                          "total_bad_header_items, total_bad_header_size, " .
                                                          "total_wl_items, total_wl_size, " .
                                                          "total_bl_items, total_bl_size, " .
                                                          "total_oversized_items, total_oversized_size) " .
                          "VALUES (?,?,NOW(),?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
                $sth3 = $dbh->prepare($insert)
                            or die (sprintf("Maia: [update_stats] Couldn't prepare query: %s", $dbh->errstr));
                $sth3->execute($user_id, $type,
                               $total_ham_items, $total_ham_size,
                               $total_spam_items, $total_spam_size,
                               $total_virus_items, $total_virus_size,
                               $total_fp_items, $total_fp_size,
                               $total_fn_items, $total_fn_size,
                               $total_banned_file_items, $total_banned_file_size,
                               $total_bad_header_items, $total_bad_header_size,
                               $total_wl_items, $total_wl_size,
                               $total_bl_items, $total_bl_size,
                               $total_oversized_items, $total_oversized_size)
                    or die (sprintf("Maia: [update_stats] Couldn't execute query: %s", $dbh->errstr));
            }
            $sth2->finish;
        }
        $sth->finish;
    }


    # Expire outdated stats summaries
    sub expire_stats($) {
        my($dbh) = @_;
        my($delete, $sth);
        my($dbtype) = get_db_type($dbh);

        $delete = "DELETE FROM maia_stats_history WHERE ";

        if ($dbtype =~ /^mysql$/si) { # MySQL

            # Maintain a year's worth of monthly summaries (12 records)
            $delete .= "(type = 'M' AND taken_at <= DATE_SUB(NOW(), INTERVAL 1 YEAR)) ";

            # Maintain a month's worth of daily summaries (31 records)
            $delete .= "OR (type = 'D' AND taken_at <= DATE_SUB(NOW(), INTERVAL 31 DAY)) ";

            # Maintain a day's worth of hourly summaries (24 records)
            $delete .= "OR (type = 'H' AND taken_at <= DATE_SUB(NOW(), INTERVAL 1 DAY))";

        } elsif ($dbtype =~ /^pg$/si) { # PostgreSQL

            # Maintain a year's worth of monthly summaries (12 records)
            $delete .= "(type = 'M' AND taken_at <= NOW() - INTERVAL '1 YEAR') ";

            # Maintain a month's worth of daily summaries (31 records)
            $delete .= "OR (type = 'D' AND taken_at <= NOW() - INTERVAL '31 DAY') ";

            # Maintain a day's worth of hourly summaries (24 records)
            $delete .= "OR (type = 'H' AND taken_at <= NOW() - INTERVAL '1 DAY')";

        }
        $sth = $dbh->prepare($delete)
                   or die (sprintf("Maia: [update_stats] Couldn't prepare query: %s", $dbh->errstr));
        $sth->execute()
            or die (sprintf("Maia: [update_stats] Couldn't execute query: %s", $dbh->errstr));

    }


    # Read the database configuration file into memory once
    open CONFIGFILE, "<" . $cfg
        or die ("Maia: [stats-snapshot] Unable to open $cfg\n");
    my($config) = "";
    my $line;
    while ($line = <CONFIGFILE>) {
        $config .= $line;
    }
    close CONFIGFILE;

    # Connect to the database
    my $dsn = get_string_key($config, "dsn");
    my $username = get_string_key($config, "username");
    my $password = get_string_key($config, "password");
    my $dbh = DBI->connect($dsn, $username, $password)
                       or die("Can't connect to SQL database");

    # What time/date is it?
    my($hour, $day, $month, $year) = (localtime)[2,3,4,5];
    $month += 1;
    $year += 1900;

    update_stats($dbh, "H");
    if ($hour == 0) { # Midnight
        update_stats($dbh, "D");
        if ($day == 1) { # First day of the month
            update_stats($dbh, "M");
            if ($month == 1) { # New Years
            	update_stats($dbh, "Y");
            }
        }
    }
    expire_stats($dbh);

    # Disconnect from the database
    $dbh->disconnect;

    # We're done.
    exit;